@@ -5,7 +5,7 @@
 
 "use strict";
 
-const astUtils = require("../ast-utils");
+const astUtils = require("./utils/ast-utils");
 
 //------------------------------------------------------------------------------
 // Rule Definition
@@ -13,6 +13,8 @@ const astUtils = require("../ast-utils");
 
 module.exports = {
     meta: {
+        type: "problem",
+
         docs: {
             description: "disallow reassigning exceptions in `catch` clauses",
             category: "Possible Errors",
