@@ -9,8 +9,7 @@
 // Requirements
 //------------------------------------------------------------------------------
 
-const lodash = require("lodash");
-const astUtils = require("../ast-utils");
+const astUtils = require("./utils/ast-utils");
 
 //------------------------------------------------------------------------------
 // Rule Definition
@@ -18,6 +17,8 @@ const astUtils = require("../ast-utils");
 
 module.exports = {
     meta: {
+        type: "problem",
+
         docs: {
             description: "disallow unused variables",
             category: "Variables",
@@ -65,7 +66,7 @@ module.exports = {
     create(context) {
         const sourceCode = context.getSourceCode();
 
-        const REST_PROPERTY_TYPE = /^(?:RestElement|(?:Experimental)?RestProperty)$/;
+        const REST_PROPERTY_TYPE = /^(?:RestElement|(?:Experimental)?RestProperty)$/u;
 
         const config = {
             vars: "all",
@@ -86,15 +87,15 @@ module.exports = {
                 config.caughtErrors = firstOption.caughtErrors || config.caughtErrors;
 
                 if (firstOption.varsIgnorePattern) {
-                    config.varsIgnorePattern = new RegExp(firstOption.varsIgnorePattern);
+                    config.varsIgnorePattern = new RegExp(firstOption.varsIgnorePattern, "u");
                 }
 
                 if (firstOption.argsIgnorePattern) {
-                    config.argsIgnorePattern = new RegExp(firstOption.argsIgnorePattern);
+                    config.argsIgnorePattern = new RegExp(firstOption.argsIgnorePattern, "u");
                 }
 
                 if (firstOption.caughtErrorsIgnorePattern) {
-                    config.caughtErrorsIgnorePattern = new RegExp(firstOption.caughtErrorsIgnorePattern);
+                    config.caughtErrorsIgnorePattern = new RegExp(firstOption.caughtErrorsIgnorePattern, "u");
                 }
             }
         }
@@ -141,7 +142,7 @@ module.exports = {
         // Helpers
         //--------------------------------------------------------------------------
 
-        const STATEMENT_TYPE = /(?:Statement|Declaration)$/;
+        const STATEMENT_TYPE = /(?:Statement|Declaration)$/u;
 
         /**
          * Determines if a given variable is being exported from a module.
@@ -223,6 +224,32 @@ module.exports = {
             return false;
         }
 
+        /**
+         * Gets a list of function definitions for a specified variable.
+         * @param {Variable} variable - eslint-scope variable object.
+         * @returns {ASTNode[]} Function nodes.
+         * @private
+         */
+        function getFunctionDefinitions(variable) {
+            const functionDefinitions = [];
+
+            variable.defs.forEach(def => {
+                const { type, node } = def;
+
+                // FunctionDeclarations
+                if (type === "FunctionName") {
+                    functionDefinitions.push(node);
+                }
+
+                // FunctionExpressions
+                if (type === "Variable" && node.init &&
+                    (node.init.type === "FunctionExpression" || node.init.type === "ArrowFunctionExpression")) {
+                    functionDefinitions.push(node.init);
+                }
+            });
+            return functionDefinitions;
+        }
+
         /**
          * Checks the position of given nodes.
          *
@@ -372,22 +399,18 @@ module.exports = {
             return ref.isRead() && (
 
                 // self update. e.g. `a += 1`, `a++`
-                (
-                    parent.type === "AssignmentExpression" &&
+                (// in RHS of an assignment for itself. e.g. `a = a + 1`
+                    ((
+                        parent.type === "AssignmentExpression" &&
                     granpa.type === "ExpressionStatement" &&
                     parent.left === id
-                ) ||
+                    ) ||
                 (
                     parent.type === "UpdateExpression" &&
                     granpa.type === "ExpressionStatement"
-                ) ||
-
-                // in RHS of an assignment for itself. e.g. `a = a + 1`
-                (
-                    rhsNode &&
-                    isInside(id, rhsNode) &&
-                    !isInsideOfStorableFunction(id, rhsNode)
-                )
+                ) || rhsNode &&
+                isInside(id, rhsNode) &&
+                !isInsideOfStorableFunction(id, rhsNode)))
             );
         }
 
@@ -435,7 +458,7 @@ module.exports = {
          * @private
          */
         function isUsedVariable(variable) {
-            const functionNodes = variable.defs.filter(def => def.type === "FunctionName").map(def => def.node),
+            const functionNodes = getFunctionDefinitions(variable),
                 isFunctionDefinition = functionNodes.length > 0;
             let rhsNode = null;
 
@@ -469,7 +492,7 @@ module.exports = {
             const posteriorParams = params.slice(params.indexOf(variable) + 1);
 
             // If any used parameters occur after this parameter, do not report.
-            return !posteriorParams.some(v => v.references.length > 0);
+            return !posteriorParams.some(v => v.references.length > 0 || v.eslintUsed);
         }
 
         /**
@@ -484,7 +507,7 @@ module.exports = {
             const childScopes = scope.childScopes;
             let i, l;
 
-            if (scope.type !== "TDZ" && (scope.type !== "global" || config.vars === "all")) {
+            if (scope.type !== "global" || config.vars === "all") {
                 for (i = 0, l = variables.length; i < l; ++i) {
                     const variable = variables[i];
 
@@ -564,39 +587,6 @@ module.exports = {
             return unusedVars;
         }
 
-        /**
-         * Gets the index of a given variable name in a given comment.
-         * @param {eslint-scope.Variable} variable - A variable to get.
-         * @param {ASTNode} comment - A comment node which includes the variable name.
-         * @returns {number} The index of the variable name's location.
-         * @private
-         */
-        function getColumnInComment(variable, comment) {
-            const namePattern = new RegExp(`[\\s,]${lodash.escapeRegExp(variable.name)}(?:$|[\\s,:])`, "g");
-
-            // To ignore the first text "global".
-            namePattern.lastIndex = comment.value.indexOf("global") + 6;
-
-            // Search a given variable name.
-            const match = namePattern.exec(comment.value);
-
-            return match ? match.index + 1 : 0;
-        }
-
-        /**
-         * Creates the correct location of a given variables.
-         * The location is at its name string in a `/*global` comment.
-         *
-         * @param {eslint-scope.Variable} variable - A variable to get its location.
-         * @returns {{line: number, column: number}} The location object for the variable.
-         * @private
-         */
-        function getLocation(variable) {
-            const comment = variable.eslintExplicitGlobalComment;
-
-            return sourceCode.getLocFromIndex(comment.range[0] + 2 + getColumnInComment(variable, comment));
-        }
-
         //--------------------------------------------------------------------------
         // Public
         //--------------------------------------------------------------------------
@@ -608,14 +598,8 @@ module.exports = {
                 for (let i = 0, l = unusedVars.length; i < l; ++i) {
                     const unusedVar = unusedVars[i];
 
-                    if (unusedVar.eslintExplicitGlobal) {
-                        context.report({
-                            node: programNode,
-                            loc: getLocation(unusedVar),
-                            message: getDefinedMessage(unusedVar),
-                            data: unusedVar
-                        });
-                    } else if (unusedVar.defs.length > 0) {
+                    // Report the first declaration.
+                    if (unusedVar.defs.length > 0) {
                         context.report({
                             node: unusedVar.identifiers[0],
                             message: unusedVar.references.some(ref => ref.isWrite())
@@ -623,6 +607,17 @@ module.exports = {
                                 : getDefinedMessage(unusedVar),
                             data: unusedVar
                         });
+
+                    // If there are no regular declaration, report the first `/*globals*/` comment directive.
+                    } else if (unusedVar.eslintExplicitGlobalComments) {
+                        const directiveComment = unusedVar.eslintExplicitGlobalComments[0];
+
+                        context.report({
+                            node: programNode,
+                            loc: astUtils.getNameLocationInGlobalDirectiveComment(sourceCode, directiveComment, unusedVar.name),
+                            message: getDefinedMessage(unusedVar),
+                            data: unusedVar
+                        });
                     }
                 }
             }
