@@ -15,10 +15,9 @@
 //------------------------------------------------------------------------------
 
 const assert = require("chai").assert,
-    CLIEngine = require("../../lib/cli-engine"),
+    CLIEngine = require("../../lib/cli-engine/index").CLIEngine,
     path = require("path"),
     sinon = require("sinon"),
-    leche = require("leche"),
     fs = require("fs"),
     os = require("os"),
     sh = require("shelljs");
@@ -37,7 +36,7 @@ describe("cli", () => {
         error: sinon.spy()
     };
     const cli = proxyquire("../../lib/cli", {
-        "./util/logging": log
+        "./shared/logging": log
     });
 
     /**
@@ -47,22 +46,21 @@ describe("cli", () => {
      * @returns {void}
      */
     function verifyCLIEngineOpts(cmd, opts) {
-        const sandbox = sinon.sandbox.create();
 
         // create a fake CLIEngine to test with
-        const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match(opts));
+        const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match(opts));
 
-        fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-        sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({});
-        sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(sinon.spy());
+        Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+        sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({});
+        sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(sinon.spy());
 
         const localCLI = proxyquire("../../lib/cli", {
-            "./cli-engine": fakeCLIEngine,
-            "./util/logging": log
+            "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+            "./shared/logging": log
         });
 
         localCLI.execute(cmd);
-        sandbox.verifyAndRestore();
+        sinon.verifyAndRestore();
     }
 
     // verifyCLIEngineOpts
@@ -84,8 +82,8 @@ describe("cli", () => {
     });
 
     afterEach(() => {
-        log.info.reset();
-        log.error.reset();
+        log.info.resetHistory();
+        log.error.resetHistory();
     });
 
     after(() => {
@@ -227,6 +225,25 @@ describe("cli", () => {
         });
     });
 
+    describe("when given a valid built-in formatter name that uses rules meta.", () => {
+        it("should execute without any errors", () => {
+            const filePath = getFixturePath("passing.js");
+            const exit = cli.execute(`-f json-with-metadata ${filePath} --no-eslintrc`);
+
+            assert.strictEqual(exit, 0);
+
+            // Check metadata.
+            const { metadata } = JSON.parse(log.info.args[0][0]);
+            const rules = new CLIEngine({ useEslintrc: false }).getRules();
+            const expectedMetadata = Array.from(rules).reduce((obj, [ruleId, rule]) => {
+                obj.rulesMeta[ruleId] = rule.meta;
+                return obj;
+            }, { rulesMeta: {} });
+
+            assert.deepStrictEqual(metadata, expectedMetadata);
+        });
+    });
+
     describe("when given an invalid built-in formatter name", () => {
         it("should execute with error", () => {
             const filePath = getFixturePath("passing.js");
@@ -296,7 +313,7 @@ describe("cli", () => {
 
             assert.isTrue(log.info.called, "Log should have been called.");
 
-            log.info.reset();
+            log.info.resetHistory();
 
             cli.execute(`--no-ignore --rule semi:2 ${passingPath}`);
             assert.isTrue(log.info.notCalled);
@@ -323,7 +340,7 @@ describe("cli", () => {
     describe("when given a directory with eslint excluded files in the directory", () => {
         it("should throw an error and not process any files", () => {
             const ignorePath = getFixturePath(".eslintignore");
-            const filePath = getFixturePath(".");
+            const filePath = getFixturePath("cli");
 
             assert.throws(() => {
                 cli.execute(`--ignore-path ${ignorePath} ${filePath}`);
@@ -467,7 +484,7 @@ describe("cli", () => {
 
             cli.execute(`--no-eslintrc --config ./conf/eslint-recommended.js --no-ignore ${files.join(" ")}`);
 
-            assert.strictEqual(log.info.args[0][0].split("\n").length, 11);
+            assert.strictEqual(log.info.args[0][0].split("\n").length, 10);
         });
     });
 
@@ -588,12 +605,21 @@ describe("cli", () => {
 
     });
 
-    describe("when given an parser name", () => {
-        it("should exit with error if parser is invalid", () => {
-            const filePath = getFixturePath("passing.js");
-            const exit = cli.execute(`--no-ignore --parser test111 ${filePath}`);
+    describe("when supplied with a plugin-loading path", () => {
+        it("should pass the option to CLIEngine", () => {
+            const examplePluginDirPath = "foo/bar";
 
-            assert.strictEqual(exit, 1);
+            verifyCLIEngineOpts(`--resolve-plugins-relative-to ${examplePluginDirPath} foo.js`, {
+                resolvePluginsRelativeTo: examplePluginDirPath
+            });
+        });
+    });
+
+    describe("when given an parser name", () => {
+        it("should exit with a fatal error if parser is invalid", () => {
+            const filePath = getFixturePath("passing.js");
+
+            assert.throws(() => cli.execute(`--no-ignore --parser test111 ${filePath}`), "Cannot find module 'test111'");
         });
 
         it("should exit with no error if parser is valid", () => {
@@ -675,21 +701,19 @@ describe("cli", () => {
     });
 
     describe("when passed --no-inline-config", () => {
-
-        const sandbox = sinon.sandbox.create();
         let localCLI;
 
         afterEach(() => {
-            sandbox.verifyAndRestore();
+            sinon.verifyAndRestore();
         });
 
         it("should pass allowInlineConfig:true to CLIEngine when --no-inline-config is used", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ allowInlineConfig: false }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ allowInlineConfig: false }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
                 errorCount: 1,
                 warningCount: 0,
                 results: [{
@@ -703,12 +727,12 @@ describe("cli", () => {
                     ]
                 }]
             });
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            fakeCLIEngine.outputFixes = sandbox.stub();
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            fakeCLIEngine.outputFixes = sinon.stub();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             localCLI.execute("--no-inline-config .");
@@ -717,21 +741,21 @@ describe("cli", () => {
         it("should not error and allowInlineConfig should be true by default", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ allowInlineConfig: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ allowInlineConfig: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
                 errorCount: 0,
                 warningCount: 0,
                 results: []
             });
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.stub();
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.stub();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute(".");
@@ -743,32 +767,30 @@ describe("cli", () => {
     });
 
     describe("when passed --fix", () => {
-
-        const sandbox = sinon.sandbox.create();
         let localCLI;
 
         afterEach(() => {
-            sandbox.verifyAndRestore();
+            sinon.verifyAndRestore();
         });
 
         it("should pass fix:true to CLIEngine when executing on files", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
                 errorCount: 0,
                 warningCount: 0,
                 results: []
             });
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.mock().once();
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.mock().once();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .");
@@ -796,17 +818,17 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.mock().withExactArgs(report);
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.mock().withExactArgs(report);
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .");
@@ -833,18 +855,18 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: sinon.match.func }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: sinon.match.func }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.getErrorResults = sandbox.stub().returns([]);
-            fakeCLIEngine.outputFixes = sandbox.mock().withExactArgs(report);
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.getErrorResults = sinon.stub().returns([]);
+            fakeCLIEngine.outputFixes = sinon.mock().withExactArgs(report);
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix --quiet .");
@@ -856,11 +878,11 @@ describe("cli", () => {
         it("should not call CLIEngine and return 1 when executing on text", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().never();
+            const fakeCLIEngine = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .", "foo = bar;");
@@ -871,31 +893,30 @@ describe("cli", () => {
     });
 
     describe("when passed --fix-dry-run", () => {
-        const sandbox = sinon.sandbox.create();
         let localCLI;
 
         afterEach(() => {
-            sandbox.verifyAndRestore();
+            sinon.verifyAndRestore();
         });
 
         it("should pass fix:true to CLIEngine when executing on files", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
                 errorCount: 0,
                 warningCount: 0,
                 results: []
             });
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.mock().never();
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .");
@@ -912,21 +933,21 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match(expectedCLIEngineOptions));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match(expectedCLIEngineOptions));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
                 errorCount: 0,
                 warningCount: 0,
                 results: []
             });
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.stub();
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.stub();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run --fix-type suggestion .");
@@ -952,17 +973,17 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.mock().never();
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .");
@@ -989,18 +1010,18 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: sinon.match.func }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: sinon.match.func }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.getErrorResults = sandbox.stub().returns([]);
-            fakeCLIEngine.outputFixes = sandbox.mock().never();
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.getErrorResults = sinon.stub().returns([]);
+            fakeCLIEngine.outputFixes = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run --quiet .");
@@ -1027,17 +1048,17 @@ describe("cli", () => {
             };
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match({ fix: true }));
+            const fakeCLIEngine = sinon.mock().withExactArgs(sinon.match({ fix: true }));
 
-            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
-            sandbox.stub(fakeCLIEngine.prototype, "executeOnText").returns(report);
-            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
-            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
-            fakeCLIEngine.outputFixes = sandbox.mock().never();
+            Object.defineProperties(fakeCLIEngine.prototype, Object.getOwnPropertyDescriptors(CLIEngine.prototype));
+            sinon.stub(fakeCLIEngine.prototype, "executeOnText").returns(report);
+            sinon.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sinon.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .", "foo = bar;");
@@ -1048,11 +1069,11 @@ describe("cli", () => {
         it("should not call CLIEngine and return 1 when used with --fix", () => {
 
             // create a fake CLIEngine to test with
-            const fakeCLIEngine = sandbox.mock().never();
+            const fakeCLIEngine = sinon.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
-                "./cli-engine": fakeCLIEngine,
-                "./util/logging": log
+                "./cli-engine/index": { CLIEngine: fakeCLIEngine },
+                "./shared/logging": log
             });
 
             const exitCode = localCLI.execute("--fix --fix-dry-run .", "foo = bar;");
@@ -1063,7 +1084,7 @@ describe("cli", () => {
 
     describe("when passing --print-config", () => {
         it("should print out the configuration", () => {
-            const filePath = getFixturePath("files");
+            const filePath = getFixturePath("xxxx");
 
             const exitCode = cli.execute(`--print-config ${filePath}`);
 
