@@ -9,7 +9,7 @@
 // Requirements
 //------------------------------------------------------------------------------
 const rule = require("../../../lib/rules/max-len"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Tests
@@ -51,6 +51,9 @@ ruleTester.run("max-len", rule, {
         }, {
             code: "// really long comment on its own line sitting here",
             options: [40, 4, { ignoreComments: true }]
+        }, {
+            code: "var foo = module.exports = {}; /* inline some other comments */ //more",
+            options: [40, 4, { ignoreComments: true }]
         },
         "var /*inline-comment*/ i = 1;",
         {
@@ -87,6 +90,9 @@ ruleTester.run("max-len", rule, {
         }, {
             code: "var foo = module.exports = {}; // really long trailing comment",
             options: [40, 4, { ignoreTrailingComments: true }]
+        }, {
+            code: "var foo = module.exports = {}; /* inline some other comments */ //more",
+            options: [40, 4, { ignoreTrailingComments: true }]
         }, {
             code: "var foo = module.exports = {}; // really long trailing comment",
             options: [40, 4, { ignoreComments: true, ignoreTrailingComments: false }]
@@ -178,6 +184,17 @@ ruleTester.run("max-len", rule, {
         {
             code: "'🙂😀😆😎😊😜😉👍'",
             options: [10]
+        },
+
+        // Astral symbols in pattern (only matched by unicode regexes)
+        {
+            code: "var longNameLongName = '𝌆𝌆'",
+            options: [5, { ignorePattern: "𝌆{2}" }]
+        },
+
+        {
+            code: "\tfoo",
+            options: [4, { tabWidth: 0 }]
         }
     ],
 
@@ -187,7 +204,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 80 },
+                    data: { lineLength: 86, maxLength: 80 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -200,7 +217,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 10 },
+                    data: { lineLength: 24, maxLength: 10 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -213,7 +230,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 15 },
+                    data: { lineLength: 22, maxLength: 15 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -226,14 +243,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 15 },
+                    data: { lineLength: 22, maxLength: 15 },
                     type: "Program",
                     line: 1,
                     column: 1
                 },
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 15 },
+                    data: { lineLength: 22, maxLength: 15 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -246,7 +263,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 20 },
+                    data: { lineLength: 56, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -261,7 +278,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 20 },
+                    data: { lineLength: 54, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -274,7 +291,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 10 },
+                    data: { lineLength: 30, maxLength: 10 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -287,7 +304,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 40 },
+                    data: { lineLength: 62, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -300,7 +317,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 40 },
+                    data: { lineLength: 57, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -312,7 +329,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 40 },
+                    data: { lineLength: 53, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -324,7 +341,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 1, maxCommentLength: 20 },
+                    data: { lineLength: 49, maxCommentLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -336,7 +353,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 1, maxCommentLength: 80 },
+                    data: { lineLength: 119, maxCommentLength: 80 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -348,7 +365,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 20 },
+                    data: { lineLength: 49, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -360,7 +377,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 40 },
+                    data: { lineLength: 73, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -377,7 +394,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 2, maxCommentLength: 28 },
+                    data: { lineLength: 29, maxCommentLength: 28 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -391,7 +408,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 2, maxCommentLength: 32 },
+                    data: { lineLength: 33, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -406,14 +423,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 2, maxCommentLength: 28 },
+                    data: { lineLength: 29, maxCommentLength: 28 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 3, maxCommentLength: 28 },
+                    data: { lineLength: 32, maxCommentLength: 28 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -428,14 +445,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 2, maxCommentLength: 32 },
+                    data: { lineLength: 33, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 3, maxCommentLength: 32 },
+                    data: { lineLength: 36, maxCommentLength: 32 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -450,14 +467,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 39 },
+                    data: { lineLength: 40, maxLength: 39 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 3, maxCommentLength: 35 },
+                    data: { lineLength: 36, maxCommentLength: 35 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -472,14 +489,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "maxComment",
-                    data: { lineNumber: 2, maxCommentLength: 32 },
+                    data: { lineLength: 33, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
                     messageId: "max",
-                    data: { lineNumber: 3, maxLength: 42 },
+                    data: { lineLength: 43, maxLength: 42 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -495,7 +512,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 20 },
+                    data: { lineLength: 51, maxLength: 20 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -510,7 +527,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 39, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -523,7 +540,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 45, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -536,7 +553,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 57, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -549,7 +566,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 39, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -563,7 +580,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 39, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -577,14 +594,14 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 2, maxLength: 29 },
+                    data: { lineLength: 37, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
                     messageId: "max",
-                    data: { lineNumber: 3, maxLength: 29 },
+                    data: { lineLength: 44, maxLength: 29 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -598,7 +615,7 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 29 },
+                    data: { lineLength: 58, maxLength: 29 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -613,7 +630,21 @@ ruleTester.run("max-len", rule, {
             errors: [
                 {
                     messageId: "max",
-                    data: { lineNumber: 1, maxLength: 10 },
+                    data: { lineLength: 12, maxLength: 10 },
+                    type: "Program",
+                    line: 1,
+                    column: 1
+                }
+            ]
+        },
+
+        {
+            code: "a",
+            options: [0],
+            errors: [
+                {
+                    messageId: "max",
+                    data: { lineLength: 1, maxLength: 0 },
                     type: "Program",
                     line: 1,
                     column: 1
