@@ -11,7 +11,7 @@
 //------------------------------------------------------------------------------
 
 const rule = require("../../../lib/rules/newline-after-var"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Fixtures
@@ -206,12 +206,12 @@ ruleTester.run("newline-after-var", rule, {
         { code: FOR_OF_LOOP_WITH_VAR, options: ["never"], parserOptions: { ecmaVersion: 6 } },
 
         // should handle export specifiers
-        { code: EXPORT_WITH_LET, options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: EXPORT_WITH_LET, options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: EXPORT_WITH_VAR, options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: EXPORT_WITH_VAR, options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: EXPORT_WITH_CONST, options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: EXPORT_WITH_CONST, options: ["always"], parserOptions: { sourceType: "module" } },
+        { code: EXPORT_WITH_LET, options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: EXPORT_WITH_LET, options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: EXPORT_WITH_VAR, options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: EXPORT_WITH_VAR, options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: EXPORT_WITH_CONST, options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: EXPORT_WITH_CONST, options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
 
         // should allow no blank line at end of block
         { code: END_OF_FUNCTION, options: ["always"] },
