@@ -10,7 +10,7 @@
 //------------------------------------------------------------------------------
 
 const rule = require("../../../lib/rules/no-eval"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Tests
@@ -37,7 +37,7 @@ ruleTester.run("no-eval", rule, {
         { code: "function foo() { var eval = 'foo'; global[eval]('foo') }", env: { node: true } },
         "this.noeval('foo');",
         "function foo() { 'use strict'; this.eval('foo'); }",
-        { code: "function foo() { this.eval('foo'); }", parserOptions: { sourceType: "module" } },
+        { code: "function foo() { this.eval('foo'); }", parserOptions: { ecmaVersion: 6, sourceType: "module" } },
         { code: "function foo() { this.eval('foo'); }", parserOptions: { ecmaFeatures: { impliedStrict: true } } },
         "var obj = {foo: function() { this.eval('foo'); }}",
         "var obj = {}; obj.foo = function() { this.eval('foo'); }",
