@@ -9,7 +9,7 @@
 //------------------------------------------------------------------------------
 
 const rule = require("../../../lib/rules/no-param-reassign"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Tests
@@ -21,7 +21,11 @@ ruleTester.run("no-param-reassign", rule, {
 
     valid: [
         "function foo(a) { var b = a; }",
+        "function foo(a) { for (b in a); }",
+        { code: "function foo(a) { for (b of a); }", parserOptions: { ecmaVersion: 6 } },
         "function foo(a) { a.prop = 'value'; }",
+        "function foo(a) { for (a.prop in obj); }",
+        { code: "function foo(a) { for (a.prop of arr); }", parserOptions: { ecmaVersion: 6 } },
         "function foo(a) { (function() { var a = 12; a++; })(); }",
         "function foo() { someGlobal = 13; }",
         { code: "function foo() { someGlobal = 13; }", globals: { someGlobal: false } },
@@ -37,6 +41,8 @@ ruleTester.run("no-param-reassign", rule, {
         { code: "function foo(a) { a.b = 0; }", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }] },
         { code: "function foo(a) { ++a.b; }", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }] },
         { code: "function foo(a) { delete a.b; }", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }] },
+        { code: "function foo(a) { for (a.b in obj); }", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }] },
+        { code: "function foo(a) { for (a.b of arr); }", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }], parserOptions: { ecmaVersion: 6 } },
         { code: "function foo(a, z) { a.b = 0; x.y = 0; }", options: [{ props: true, ignorePropertyModificationsFor: ["a", "x"] }] },
         { code: "function foo(a) { a.b.c = 0;}", options: [{ props: true, ignorePropertyModificationsFor: ["a"] }] },
         {
@@ -53,6 +59,33 @@ ruleTester.run("no-param-reassign", rule, {
             code: "function foo(a) { ({...a.b} = obj); }",
             options: [{ props: false }],
             parserOptions: { ecmaVersion: 2018 }
+        },
+        {
+            code: "function foo(a) { for (obj[a.b] in obj); }",
+            options: [{ props: true }]
+        },
+        {
+            code: "function foo(a) { for (obj[a.b] of arr); }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 }
+        },
+        {
+            code: "function foo(a) { for (bar in a.b); }",
+            options: [{ props: true }]
+        },
+        {
+            code: "function foo(a) { for (bar of a.b); }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 }
+        },
+        {
+            code: "function foo(a) { for (bar in baz) a.b; }",
+            options: [{ props: true }]
+        },
+        {
+            code: "function foo(a) { for (bar of baz) a.b; }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 }
         }
     ],
 
@@ -68,6 +101,8 @@ ruleTester.run("no-param-reassign", rule, {
         { code: "function foo([, {bar}]) { bar = 13; }", parserOptions: { ecmaVersion: 6 }, errors: [{ message: "Assignment to function parameter 'bar'." }] },
         { code: "function foo(bar) { ({bar} = {}); }", parserOptions: { ecmaVersion: 6 }, errors: [{ message: "Assignment to function parameter 'bar'." }] },
         { code: "function foo(bar) { ({x: [, bar = 0]} = {}); }", parserOptions: { ecmaVersion: 6 }, errors: [{ message: "Assignment to function parameter 'bar'." }] },
+        { code: "function foo(bar) { for (bar in baz); }", errors: [{ message: "Assignment to function parameter 'bar'." }] },
+        { code: "function foo(bar) { for (bar of baz); }", parserOptions: { ecmaVersion: 6 }, errors: [{ message: "Assignment to function parameter 'bar'." }] },
 
         {
             code: "function foo(bar) { bar.a = 0; }",
@@ -89,6 +124,17 @@ ruleTester.run("no-param-reassign", rule, {
             options: [{ props: true }],
             errors: [{ message: "Assignment to property of function parameter 'bar'." }]
         },
+        {
+            code: "function foo(bar) { for (bar.a in {}); }",
+            options: [{ props: true }],
+            errors: [{ message: "Assignment to property of function parameter 'bar'." }]
+        },
+        {
+            code: "function foo(bar) { for (bar.a of []); }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [{ message: "Assignment to property of function parameter 'bar'." }]
+        },
         {
             code: "function foo(bar) { (bar ? bar : [])[0] = 1; }",
             options: [{ props: true }],
@@ -139,6 +185,18 @@ ruleTester.run("no-param-reassign", rule, {
             options: [{ props: true }],
             parserOptions: { ecmaVersion: 2018 },
             errors: [{ message: "Assignment to property of function parameter 'a'." }]
+        },
+        {
+            code: "function foo(a) { for ({bar: a.b} in {}); }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [{ message: "Assignment to property of function parameter 'a'." }]
+        },
+        {
+            code: "function foo(a) { for ([a.b] of []); }",
+            options: [{ props: true }],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [{ message: "Assignment to property of function parameter 'a'." }]
         }
     ]
 });
