@@ -10,7 +10,7 @@
 
 const resolvePath = require("path").resolve,
     rule = require("../../../lib/rules/object-curly-spacing"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Tests
@@ -26,6 +26,8 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var obj = { foo: bar, baz: qux };", options: ["always"] },
         { code: "var obj = { foo: { bar: quxx }, baz: qux };", options: ["always"] },
         { code: "var obj = {\nfoo: bar,\nbaz: qux\n};", options: ["always"] },
+        { code: "var obj = { /**/foo:bar/**/ };", options: ["always"] },
+        { code: "var obj = { //\nfoo:bar };", options: ["always"] },
 
         // always - destructuring
         { code: "var { x } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
@@ -33,6 +35,8 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var { x,y } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {\nx,y } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {\nx,y\n} = z", options: ["always"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var { /**/x/**/ } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var { //\nx } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
         { code: "var { x = 10, y } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
         { code: "var { x: { z }, y } = y", options: ["always"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {\ny,\n} = x", options: ["always"], parserOptions: { ecmaVersion: 6 } },
@@ -40,21 +44,27 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var { y: x } = x", options: ["always"], parserOptions: { ecmaVersion: 6 } },
 
         // always - import / export
-        { code: "import door from 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import * as door from 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import { door } from 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import {\ndoor } from 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "export { door } from 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import { house, mouse } from 'caravan'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import house, { mouse } from 'caravan'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import door, { house, mouse } from 'caravan'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "var door = 0;export { door }", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import 'room'", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import { bar as x } from 'foo';", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import { x, } from 'foo';", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "import {\nx,\n} from 'foo';", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "export { x, } from 'foo';", options: ["always"], parserOptions: { sourceType: "module" } },
-        { code: "export {\nx,\n} from 'foo';", options: ["always"], parserOptions: { sourceType: "module" } },
+        { code: "import door from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import * as door from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { door } from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {\ndoor } from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { /**/door/**/ } from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { //\ndoor } from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export { door } from 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { house, mouse } from 'caravan'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import house, { mouse } from 'caravan'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import door, { house, mouse } from 'caravan'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var door = 0;export { door }", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import 'room'", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { bar as x } from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { x, } from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {\nx,\n} from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export { x, } from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {\nx,\n} from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export { /**/x/**/ } from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export { //\nx } from 'foo';", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var x = 1;\nexport { /**/x/**/ };", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var x = 1;\nexport { //\nx };", options: ["always"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
 
         // always - empty object
         { code: "var foo = {};", options: ["always"] },
@@ -84,6 +94,10 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var obj = {foo: {\nbar: quxx}, baz: qux\n};", options: ["never"] },
         { code: "var obj = {foo: {\nbar: quxx\n}, baz: qux};", options: ["never"] },
         { code: "var obj = {\nfoo: bar,\nbaz: qux\n};", options: ["never"] },
+        { code: "var obj = {foo: bar, baz: qux /* */};", options: ["never"] },
+        { code: "var obj = {/* */ foo: bar, baz: qux};", options: ["never"] },
+        { code: "var obj = {//\n foo: bar};", options: ["never"] },
+        { code: "var obj = { // line comment exception\n foo: bar};", options: ["never"] },
 
         // never - destructuring
         { code: "var {x} = y", options: ["never"], parserOptions: { ecmaVersion: 6 } },
@@ -97,25 +111,39 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var {\ny,\n} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {y,} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {y:x} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var {/* */ y} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var {y /* */} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var {//\n y} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
+        { code: "var { // line comment exception\n y} = x", options: ["never"], parserOptions: { ecmaVersion: 6 } },
 
         // never - import / export
-        { code: "import door from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import * as door from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {door} from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {door} from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {\ndoor} from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {\ndoor\n} from 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {house,mouse} from 'caravan'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {house, mouse} from 'caravan'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "var door = 0;export {door}", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import 'room'", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import x, {bar} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import x, {bar, baz} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {bar as y} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {x,} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "import {\nx,\n} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {x,} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {\nx,\n} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
+        { code: "import door from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import * as door from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {/* */ door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {/* */ door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {door /* */} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {door /* */} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {//\n door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {//\n door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var door = foo;\nexport {//\n door}", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import { // line comment exception\n door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export { // line comment exception\n door} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var door = foo; export { // line comment exception\n door}", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {\ndoor} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {\ndoor\n} from 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {house,mouse} from 'caravan'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {house, mouse} from 'caravan'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "var door = 0;export {door}", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import 'room'", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import x, {bar} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import x, {bar, baz} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {bar as y} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {x,} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "import {\nx,\n} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {x,} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {\nx,\n} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
 
 
         // never - empty object
@@ -132,16 +160,16 @@ ruleTester.run("object-curly-spacing", rule, {
         { code: "var [] = foo;", parserOptions: { ecmaVersion: 6 } },
         { code: "var {a: {}} = foo;", parserOptions: { ecmaVersion: 6 } },
         { code: "var {a: []} = foo;", parserOptions: { ecmaVersion: 6 } },
-        { code: "import {} from 'foo';", parserOptions: { sourceType: "module" } },
-        { code: "export {} from 'foo';", parserOptions: { sourceType: "module" } },
-        { code: "export {};", parserOptions: { sourceType: "module" } },
+        { code: "import {} from 'foo';", parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {} from 'foo';", parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {};", parserOptions: { ecmaVersion: 6, sourceType: "module" } },
         { code: "var {} = foo;", options: ["never"], parserOptions: { ecmaVersion: 6 } },
         { code: "var [] = foo;", options: ["never"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {a: {}} = foo;", options: ["never"], parserOptions: { ecmaVersion: 6 } },
         { code: "var {a: []} = foo;", options: ["never"], parserOptions: { ecmaVersion: 6 } },
-        { code: "import {} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {} from 'foo';", options: ["never"], parserOptions: { sourceType: "module" } },
-        { code: "export {};", options: ["never"], parserOptions: { sourceType: "module" } },
+        { code: "import {} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {} from 'foo';", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
+        { code: "export {};", options: ["never"], parserOptions: { ecmaVersion: 6, sourceType: "module" } },
 
         // https://github.com/eslint/eslint/issues/6940
         {
@@ -156,7 +184,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import {bar} from 'foo.js';",
             output: "import { bar } from 'foo.js';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -176,7 +204,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import { bar as y} from 'foo.js';",
             output: "import { bar as y } from 'foo.js';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required before '}'.",
@@ -190,7 +218,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import {bar as y} from 'foo.js';",
             output: "import { bar as y } from 'foo.js';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -210,7 +238,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import { bar} from 'foo.js';",
             output: "import { bar } from 'foo.js';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required before '}'.",
@@ -224,7 +252,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import x, { bar} from 'foo';",
             output: "import x, { bar } from 'foo';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required before '}'.",
@@ -235,11 +263,53 @@ ruleTester.run("object-curly-spacing", rule, {
 
             ]
         },
+        {
+            code: "import x, { bar/* */} from 'foo';",
+            output: "import x, { bar/* */ } from 'foo';",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "A space is required before '}'.",
+                    type: "ImportDeclaration",
+                    line: 1,
+                    column: 21
+                }
+            ]
+        },
+        {
+            code: "import x, {/* */bar } from 'foo';",
+            output: "import x, { /* */bar } from 'foo';",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ImportDeclaration",
+                    line: 1,
+                    column: 11
+                }
+            ]
+        },
+        {
+            code: "import x, {//\n bar } from 'foo';",
+            output: "import x, { //\n bar } from 'foo';",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ImportDeclaration",
+                    line: 1,
+                    column: 11
+                }
+            ]
+        },
         {
             code: "import x, { bar, baz} from 'foo';",
             output: "import x, { bar, baz } from 'foo';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required before '}'.",
@@ -254,7 +324,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import x, {bar} from 'foo';",
             output: "import x, { bar } from 'foo';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -275,7 +345,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import x, {bar, baz} from 'foo';",
             output: "import x, { bar, baz } from 'foo';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -295,7 +365,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import {bar,} from 'foo';",
             output: "import { bar, } from 'foo';",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -316,7 +386,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "import { bar, } from 'foo';",
             output: "import {bar,} from 'foo';",
             options: ["never"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "There should be no space after '{'.",
@@ -332,11 +402,31 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "import { /* */ bar, /* */ } from 'foo';",
+            output: "import {/* */ bar, /* */} from 'foo';",
+            options: ["never"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "There should be no space after '{'.",
+                    type: "ImportDeclaration",
+                    line: 1,
+                    column: 8
+                },
+                {
+                    message: "There should be no space before '}'.",
+                    type: "ImportDeclaration",
+                    line: 1,
+                    column: 27
+                }
+            ]
+        },
         {
             code: "var bar = 0;\nexport {bar};",
             output: "var bar = 0;\nexport { bar };",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -352,6 +442,60 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var bar = 0;\nexport {/* */ bar /* */};",
+            output: "var bar = 0;\nexport { /* */ bar /* */ };",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ExportNamedDeclaration",
+                    line: 2,
+                    column: 8
+                },
+                {
+                    message: "A space is required before '}'.",
+                    type: "ExportNamedDeclaration",
+                    line: 2,
+                    column: 24
+                }
+            ]
+        },
+        {
+            code: "var bar = 0;\nexport {//\n bar };",
+            output: "var bar = 0;\nexport { //\n bar };",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ExportNamedDeclaration",
+                    line: 2,
+                    column: 8
+                }
+            ]
+        },
+        {
+            code: "var bar = 0;\nexport { /* */ bar /* */ };",
+            output: "var bar = 0;\nexport {/* */ bar /* */};",
+            options: ["never"],
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
+            errors: [
+                {
+                    message: "There should be no space after '{'.",
+                    type: "ExportNamedDeclaration",
+                    line: 2,
+                    column: 8
+                },
+                {
+                    message: "There should be no space before '}'.",
+                    type: "ExportNamedDeclaration",
+                    line: 2,
+                    column: 26
+                }
+            ]
+        },
 
         // always - arraysInObjects
         {
@@ -530,6 +674,32 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var obj = {/* */foo: bar, baz: qux };",
+            output: "var obj = { /* */foo: bar, baz: qux };",
+            options: ["always"],
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ObjectExpression",
+                    line: 1,
+                    column: 11
+                }
+            ]
+        },
+        {
+            code: "var obj = {//\n foo: bar };",
+            output: "var obj = { //\n foo: bar };",
+            options: ["always"],
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ObjectExpression",
+                    line: 1,
+                    column: 11
+                }
+            ]
+        },
         {
             code: "var obj = { foo: bar, baz: qux};",
             output: "var obj = { foo: bar, baz: qux };",
@@ -543,6 +713,19 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var obj = { foo: bar, baz: qux/* */};",
+            output: "var obj = { foo: bar, baz: qux/* */ };",
+            options: ["always"],
+            errors: [
+                {
+                    message: "A space is required before '}'.",
+                    type: "ObjectExpression",
+                    line: 1,
+                    column: 36
+                }
+            ]
+        },
         {
             code: "var obj = { foo: bar, baz: qux };",
             output: "var obj = {foo: bar, baz: qux};",
@@ -575,6 +758,19 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var obj = {foo: bar, baz: qux /* */ };",
+            output: "var obj = {foo: bar, baz: qux /* */};",
+            options: ["never"],
+            errors: [
+                {
+                    message: "There should be no space before '}'.",
+                    type: "ObjectExpression",
+                    line: 1,
+                    column: 37
+                }
+            ]
+        },
         {
             code: "var obj = { foo: bar, baz: qux};",
             output: "var obj = {foo: bar, baz: qux};",
@@ -588,6 +784,32 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var obj = { /* */ foo: bar, baz: qux};",
+            output: "var obj = {/* */ foo: bar, baz: qux};",
+            options: ["never"],
+            errors: [
+                {
+                    message: "There should be no space after '{'.",
+                    type: "ObjectExpression",
+                    line: 1,
+                    column: 11
+                }
+            ]
+        },
+        {
+            code: "var obj = { // line comment exception\n foo: bar };",
+            output: "var obj = { // line comment exception\n foo: bar};",
+            options: ["never"],
+            errors: [
+                {
+                    message: "There should be no space before '}'.",
+                    type: "ObjectExpression",
+                    line: 2,
+                    column: 11
+                }
+            ]
+        },
         {
             code: "var obj = { foo: { bar: quxx}, baz: qux};",
             output: "var obj = {foo: {bar: quxx}, baz: qux};",
@@ -630,7 +852,7 @@ ruleTester.run("object-curly-spacing", rule, {
             code: "export const thing = {value: 1 };",
             output: "export const thing = { value: 1 };",
             options: ["always"],
-            parserOptions: { sourceType: "module" },
+            parserOptions: { ecmaVersion: 6, sourceType: "module" },
             errors: [
                 {
                     message: "A space is required after '{'.",
@@ -676,6 +898,48 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var { x, y/* */} = y",
+            output: "var { x, y/* */ } = y",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                {
+                    message: "A space is required before '}'.",
+                    type: "ObjectPattern",
+                    line: 1,
+                    column: 16
+                }
+            ]
+        },
+        {
+            code: "var {/* */x, y } = y",
+            output: "var { /* */x, y } = y",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ObjectPattern",
+                    line: 1,
+                    column: 5
+                }
+            ]
+        },
+        {
+            code: "var {//\n x } = y",
+            output: "var { //\n x } = y",
+            options: ["always"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                {
+                    message: "A space is required after '{'.",
+                    type: "ObjectPattern",
+                    line: 1,
+                    column: 5
+                }
+            ]
+        },
         {
             code: "var { x, y } = y",
             output: "var {x, y} = y",
@@ -710,6 +974,34 @@ ruleTester.run("object-curly-spacing", rule, {
                 }
             ]
         },
+        {
+            code: "var {x, y/* */ } = y",
+            output: "var {x, y/* */} = y",
+            options: ["never"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                {
+                    message: "There should be no space before '}'.",
+                    type: "ObjectPattern",
+                    line: 1,
+                    column: 16
+                }
+            ]
+        },
+        {
+            code: "var { /* */x, y} = y",
+            output: "var {/* */x, y} = y",
+            options: ["never"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                {
+                    message: "There should be no space after '{'.",
+                    type: "ObjectPattern",
+                    line: 1,
+                    column: 5
+                }
+            ]
+        },
         {
             code: "var { x=10} = y",
             output: "var { x=10 } = y",
