@@ -10,7 +10,7 @@
 //------------------------------------------------------------------------------
 
 const rule = require("../../../lib/rules/sort-keys"),
-    RuleTester = require("../../../lib/testers/rule-tester");
+    { RuleTester } = require("../../../lib/rule-tester");
 
 //------------------------------------------------------------------------------
 // Tests
@@ -22,6 +22,10 @@ ruleTester.run("sort-keys", rule, {
     valid: [
 
         // default (asc)
+        { code: "var obj = {'':1, [``]:2}", options: [], parserOptions: { ecmaVersion: 6 } },
+        { code: "var obj = {[``]:1, '':2}", options: [], parserOptions: { ecmaVersion: 6 } },
+        { code: "var obj = {'':1, a:2}", options: [] },
+        { code: "var obj = {[``]:1, a:2}", options: [], parserOptions: { ecmaVersion: 6 } },
         { code: "var obj = {_:2, a:1, b:3} // default", options: [] },
         { code: "var obj = {a:1, b:3, c:2}", options: [] },
         { code: "var obj = {a:2, b:3, b_:1}", options: [] },
@@ -32,6 +36,8 @@ ruleTester.run("sort-keys", rule, {
 
         // ignore non-simple computed properties.
         { code: "var obj = {a:1, b:3, [a + b]: -1, c:2}", options: [], parserOptions: { ecmaVersion: 6 } },
+        { code: "var obj = {'':1, [f()]:2, a:3}", options: [], parserOptions: { ecmaVersion: 6 } },
+        { code: "var obj = {a:1, [b++]:2, '':3}", options: ["desc"], parserOptions: { ecmaVersion: 6 } },
 
         // ignore properties separated by spread properties
         { code: "var obj = {a:1, ...z, b:1}", options: [], parserOptions: { ecmaVersion: 2018 } },
@@ -39,6 +45,8 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {...a, b:1, ...c, d:1}", options: [], parserOptions: { ecmaVersion: 2018 } },
         { code: "var obj = {...a, b:1, ...d, ...c, e:2, z:5}", options: [], parserOptions: { ecmaVersion: 2018 } },
         { code: "var obj = {b:1, ...c, ...d, e:2}", options: [], parserOptions: { ecmaVersion: 2018 } },
+        { code: "var obj = {a:1, ...z, '':2}", options: [], parserOptions: { ecmaVersion: 2018 } },
+        { code: "var obj = {'':1, ...z, 'a':2}", options: ["desc"], parserOptions: { ecmaVersion: 2018 } },
 
         // not ignore properties not separated by spread properties
         { code: "var obj = {...z, a:1, b:1}", options: [], parserOptions: { ecmaVersion: 2018 } },
@@ -65,6 +73,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {1:1, '11':2, 2:4, A:3}", options: ["asc"] },
         { code: "var obj = {'#':1, 'Z':2, À:3, è:4}", options: ["asc"] },
 
+        // asc, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {a:1, c:2, b:3}", options: ["asc", { minKeys: 4 }] },
+
         // asc, insensitive
         { code: "var obj = {_:2, a:1, b:3} // asc, insensitive", options: ["asc", { caseSensitive: false }] },
         { code: "var obj = {a:1, b:3, c:2}", options: ["asc", { caseSensitive: false }] },
@@ -75,6 +86,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {1:1, '11':2, 2:4, A:3}", options: ["asc", { caseSensitive: false }] },
         { code: "var obj = {'#':1, 'Z':2, À:3, è:4}", options: ["asc", { caseSensitive: false }] },
 
+        // asc, insensitive, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {$:1, A:3, _:2, a:4}", options: ["asc", { caseSensitive: false, minKeys: 5 }] },
+
         // asc, natural
         { code: "var obj = {_:2, a:1, b:3} // asc, natural", options: ["asc", { natural: true }] },
         { code: "var obj = {a:1, b:3, c:2}", options: ["asc", { natural: true }] },
@@ -84,6 +98,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {1:1, 2:4, '11':2, A:3}", options: ["asc", { natural: true }] },
         { code: "var obj = {'#':1, 'Z':2, À:3, è:4}", options: ["asc", { natural: true }] },
 
+        // asc, natural, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {b_:1, a:2, b:3}", options: ["asc", { natural: true, minKeys: 4 }] },
+
         // asc, natural, insensitive
         { code: "var obj = {_:2, a:1, b:3} // asc, natural, insensitive", options: ["asc", { natural: true, caseSensitive: false }] },
         { code: "var obj = {a:1, b:3, c:2}", options: ["asc", { natural: true, caseSensitive: false }] },
@@ -94,6 +111,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {1:1, 2:4, '11':2, A:3}", options: ["asc", { natural: true, caseSensitive: false }] },
         { code: "var obj = {'#':1, 'Z':2, À:3, è:4}", options: ["asc", { natural: true, caseSensitive: false }] },
 
+        // asc, natural, insensitive, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {a:1, _:2, b:3}", options: ["asc", { natural: true, caseSensitive: false, minKeys: 4 }] },
+
         // desc
         { code: "var obj = {b:3, a:1, _:2} // desc", options: ["desc"] },
         { code: "var obj = {c:2, b:3, a:1}", options: ["desc"] },
@@ -103,6 +123,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {A:3, 2:4, '11':2, 1:1}", options: ["desc"] },
         { code: "var obj = {è:4, À:3, 'Z':2, '#':1}", options: ["desc"] },
 
+        // desc, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {a:1, c:2, b:3}", options: ["desc", { minKeys: 4 }] },
+
         // desc, insensitive
         { code: "var obj = {b:3, a:1, _:2} // desc, insensitive", options: ["desc", { caseSensitive: false }] },
         { code: "var obj = {c:2, b:3, a:1}", options: ["desc", { caseSensitive: false }] },
@@ -113,6 +136,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {A:3, 2:4, '11':2, 1:1}", options: ["desc", { caseSensitive: false }] },
         { code: "var obj = {è:4, À:3, 'Z':2, '#':1}", options: ["desc", { caseSensitive: false }] },
 
+        // desc, insensitive, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {$:1, _:2, A:3, a:4}", options: ["desc", { caseSensitive: false, minKeys: 5 }] },
+
         // desc, natural
         { code: "var obj = {b:3, a:1, _:2} // desc, natural", options: ["desc", { natural: true }] },
         { code: "var obj = {c:2, b:3, a:1}", options: ["desc", { natural: true }] },
@@ -122,6 +148,9 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {A:3, '11':2, 2:4, 1:1}", options: ["desc", { natural: true }] },
         { code: "var obj = {è:4, À:3, 'Z':2, '#':1}", options: ["desc", { natural: true }] },
 
+        // desc, natural, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {b_:1, a:2, b:3}", options: ["desc", { natural: true, minKeys: 4 }] },
+
         // desc, natural, insensitive
         { code: "var obj = {b:3, a:1, _:2} // desc, natural, insensitive", options: ["desc", { natural: true, caseSensitive: false }] },
         { code: "var obj = {c:2, b:3, a:1}", options: ["desc", { natural: true, caseSensitive: false }] },
@@ -130,11 +159,23 @@ ruleTester.run("sort-keys", rule, {
         { code: "var obj = {C:2, c:3, b_:1}", options: ["desc", { natural: true, caseSensitive: false }] },
         { code: "var obj = {a:4, A:3, _:2, $:1}", options: ["desc", { natural: true, caseSensitive: false }] },
         { code: "var obj = {A:3, '11':2, 2:4, 1:1}", options: ["desc", { natural: true, caseSensitive: false }] },
-        { code: "var obj = {è:4, À:3, 'Z':2, '#':1}", options: ["desc", { natural: true, caseSensitive: false }] }
+        { code: "var obj = {è:4, À:3, 'Z':2, '#':1}", options: ["desc", { natural: true, caseSensitive: false }] },
+
+        // desc, natural, insensitive, minKeys should ignore unsorted keys when number of keys is less than minKeys
+        { code: "var obj = {a:1, _:2, b:3}", options: ["desc", { natural: true, caseSensitive: false, minKeys: 4 }] }
     ],
     invalid: [
 
         // default (asc)
+        {
+            code: "var obj = {a:1, '':2} // default",
+            errors: ["Expected object keys to be in ascending order. '' should be before 'a'."]
+        },
+        {
+            code: "var obj = {a:1, [``]:2} // default",
+            parserOptions: { ecmaVersion: 6 },
+            errors: ["Expected object keys to be in ascending order. '' should be before 'a'."]
+        },
         {
             code: "var obj = {a:1, _:2, b:3} // default",
             errors: ["Expected object keys to be in ascending order. '_' should be before 'a'."]
@@ -210,6 +251,31 @@ ruleTester.run("sort-keys", rule, {
             parserOptions: { ecmaVersion: 2018 },
             errors: ["Expected object keys to be in descending order. 'b' should be before 'a'."]
         },
+        {
+            code: "var obj = {...z, '':1, a:2}",
+            options: ["desc"],
+            parserOptions: { ecmaVersion: 2018 },
+            errors: ["Expected object keys to be in descending order. 'a' should be before ''."]
+        },
+
+        // ignore non-simple computed properties, but their position shouldn't affect other comparisons.
+        {
+            code: "var obj = {a:1, [b+c]:2, '':3}",
+            parserOptions: { ecmaVersion: 6 },
+            errors: ["Expected object keys to be in ascending order. '' should be before 'a'."]
+        },
+        {
+            code: "var obj = {'':1, [b+c]:2, a:3}",
+            options: ["desc"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: ["Expected object keys to be in descending order. 'a' should be before ''."]
+        },
+        {
+            code: "var obj = {b:1, [f()]:2, '':3, a:4}",
+            options: ["desc"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: ["Expected object keys to be in descending order. 'a' should be before ''."]
+        },
 
         // not ignore simple computed properties.
         {
@@ -278,6 +344,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // asc, minKeys should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["asc", { minKeys: 3 }],
+            errors: [
+                "Expected object keys to be in ascending order. '_' should be before 'a'."
+            ]
+        },
+
         // asc, insensitive
         {
             code: "var obj = {a:1, _:2, b:3} // asc, insensitive",
@@ -322,6 +397,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // asc, insensitive, minKeys should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["asc", { caseSensitive: false, minKeys: 3 }],
+            errors: [
+                "Expected object keys to be in insensitive ascending order. '_' should be before 'a'."
+            ]
+        },
+
         // asc, natural
         {
             code: "var obj = {a:1, _:2, b:3} // asc, natural",
@@ -373,6 +457,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // asc, natural, minKeys should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["asc", { natural: true, minKeys: 2 }],
+            errors: [
+                "Expected object keys to be in natural ascending order. '_' should be before 'a'."
+            ]
+        },
+
         // asc, natural, insensitive
         {
             code: "var obj = {a:1, _:2, b:3} // asc, natural, insensitive",
@@ -417,7 +510,31 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // asc, natural, insensitive, minKeys should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["asc", { natural: true, caseSensitive: false, minKeys: 3 }],
+            errors: [
+                "Expected object keys to be in natural insensitive ascending order. '_' should be before 'a'."
+            ]
+        },
+
         // desc
+        {
+            code: "var obj = {'':1, a:'2'} // desc",
+            options: ["desc"],
+            errors: [
+                "Expected object keys to be in descending order. 'a' should be before ''."
+            ]
+        },
+        {
+            code: "var obj = {[``]:1, a:'2'} // desc",
+            options: ["desc"],
+            parserOptions: { ecmaVersion: 6 },
+            errors: [
+                "Expected object keys to be in descending order. 'a' should be before ''."
+            ]
+        },
         {
             code: "var obj = {a:1, _:2, b:3} // desc",
             options: ["desc"],
@@ -471,6 +588,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // desc, minKeys should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["desc", { minKeys: 3 }],
+            errors: [
+                "Expected object keys to be in descending order. 'b' should be before '_'."
+            ]
+        },
+
         // desc, insensitive
         {
             code: "var obj = {a:1, _:2, b:3} // desc, insensitive",
@@ -525,6 +651,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // desc, insensitive should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["desc", { caseSensitive: false, minKeys: 2 }],
+            errors: [
+                "Expected object keys to be in insensitive descending order. 'b' should be before '_'."
+            ]
+        },
+
         // desc, natural
         {
             code: "var obj = {a:1, _:2, b:3} // desc, natural",
@@ -580,6 +715,15 @@ ruleTester.run("sort-keys", rule, {
             ]
         },
 
+        // desc, natural should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["desc", { natural: true, minKeys: 3 }],
+            errors: [
+                "Expected object keys to be in natural descending order. 'b' should be before '_'."
+            ]
+        },
+
         // desc, natural, insensitive
         {
             code: "var obj = {a:1, _:2, b:3} // desc, natural, insensitive",
@@ -633,6 +777,15 @@ ruleTester.run("sort-keys", rule, {
                 "Expected object keys to be in natural insensitive descending order. 'À' should be before '#'.",
                 "Expected object keys to be in natural insensitive descending order. 'è' should be before 'Z'."
             ]
+        },
+
+        // desc, natural, insensitive should error when number of keys is greater than or equal to minKeys
+        {
+            code: "var obj = {a:1, _:2, b:3}",
+            options: ["desc", { natural: true, caseSensitive: false, minKeys: 2 }],
+            errors: [
+                "Expected object keys to be in natural insensitive descending order. 'b' should be before '_'."
+            ]
         }
     ]
 });
